<p align="center">
    <img alt="Plone Logo" width="200px" src="https://raw.githubusercontent.com/plone/.github/main/plone-logo.png">
</p>

<h1 align="center">
  Plone Distributions
</h1>

Package supporting the (easy) implementation of a Plone distribution.


## What is a Plone distribution

A Plone distribution is a pre-packaged version of Plone that includes specific features, themes, modules, and configurations.
It is a convenient way to get a specific type of website up and running quickly, as the distribution includes everything needed to run that type of site.

Examples of Plone distributions include:

- [SENAITE](https://www.senaite.com)
- [Quaive](https://quaivecloud.com/)
- [Portal Modelo](https://www.interlegis.leg.br/produtos-servicos/portal-modelo/)
- [Portal Padrão](https://identidade-digital-de-governo-plone.readthedocs.io/en/latest/)

### Similar concepts in other CMSs

- **Drupal:** Drupal has distributions for blogs, e-commerce sites, and intranet portals.

- **WordPress:** WordPress has a similar concept in the form of "WordPress Multisite," which allows users to run multiple websites from a single installation of WordPress.

- **Joomla:** Joomla has a similar concept in the form of "Joomla Templates," which are pre-designed templates for Joomla websites.

- **TYPO3:** TYPO3 has a similar concept in the form of "TYPO3 Distributions," which are pre-configured installations of TYPO3 for specific types of websites.

## `plone.distribution` versions

| Releases |Description | Status | Supported Plone Versions |
| --- | --- | --- | --- |
| 4.x | Core package of Plone | In development | 6.2 |
| 3.x | Core package of Plone | Maintenance | 6.1 |
| 2.x | Add-on package, uses plone.exportimport for content creation. | Maintenance | 6.0 |
| 1.x | Add-on package, uses collective.exportimport for content creation. | Deprecated | 6.0 |

## Create a new distribution

See the official documentation at [Create a Plone distribution](https://6.docs.plone.org/developer-guide/create-a-distribution.html).

## This project is supported by

<p align="left">
    <a href="https://plone.org/foundation/">
      <img alt="Plone Logo" width="200px" src="https://raw.githubusercontent.com/plone/.github/main/plone-foundation.png">
    </a>
</p>

## License

The project is licensed under the GPLv2.
